summaryrefslogtreecommitdiff
path: root/src/core/wee-log.c
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2007-11-24 18:08:41 +0100
committerSebastien Helleu <flashcode@flashtux.org>2007-11-24 18:08:41 +0100
commitab2dbe8151fe078caf4ed26bacb25be656e5aa94 (patch)
treedd810521c1c71b5cae862076163d6cab962e4ecb /src/core/wee-log.c
parent26f31bb367bd7f7b99095451c8513552404cf1c2 (diff)
downloadweechat-ab2dbe8151fe078caf4ed26bacb25be656e5aa94.zip
Renamed WeeChat log functions
Diffstat (limited to 'src/core/wee-log.c')
-rw-r--r--src/core/wee-log.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/core/wee-log.c b/src/core/wee-log.c
index 0e2619c41..1363c6d4a 100644
--- a/src/core/wee-log.c
+++ b/src/core/wee-log.c
@@ -46,11 +46,11 @@ FILE *weechat_log_file = NULL; /* WeeChat log file */
/*
* weechat_log_open: initialize log file
*/
int
-weechat_log_open (char *filename, char *mode)
+log_open (char *filename, char *mode)
{
int filename_length;
@@ -95,13 +95,13 @@ weechat_log_open (char *filename, char *mode)
}
/*
* weechat_log_init: initialize log file
*/
void
-weechat_log_init ()
+log_init ()
{
- if (!weechat_log_open (NULL, "w"))
+ if (!log_open (NULL, "w"))
{
string_iconv_fprintf (stderr,
_("Error: unable to create/append to log file (weechat.log)\n"
@@ -112,11 +112,11 @@ weechat_log_init ()
}
/*
* weechat_log_printf: write a message in WeeChat log (<weechat_home>/weechat.log)
*/
void
-weechat_log_printf (char *message, ...)
+log_printf (char *message, ...)
{
static char buffer[4096];
char *ptr_buffer;
@@ -156,11 +156,11 @@ weechat_log_printf (char *message, ...)
}
/*
* weechat_log_close: close log file
*/
void
-weechat_log_close ()
+log_close ()
{
/* close log file */
if (weechat_log_file)
@@ -181,11 +181,11 @@ weechat_log_close ()
}
/*
* weechat_log_crash_rename: rename log file when crashing
*/
int
-weechat_log_crash_rename ()
+log_crash_rename ()
{
char *old_name, *new_name;
int length;
@@ -199,7 +199,7 @@ weechat_log_crash_rename ()
if (!old_name)
return 0;
- weechat_log_close ();
+ log_close ();
length = strlen (weechat_home) + 128;
new_name = (char *) malloc (length);
@@ -218,7 +218,7 @@ weechat_log_crash_rename ()
{
string_iconv_fprintf (stderr, "*** Full crash dump was saved to %s file.\n",
new_name);
- weechat_log_open (new_name, "a");
+ log_open (new_name, "a");
free (old_name);
free (new_name);
return 1;
@@ -227,6 +227,6 @@ weechat_log_crash_rename ()
}
free (old_name);
- weechat_log_open (NULL, "a");
+ log_open (NULL, "a");
return 0;
}
@@ -46,11 +46,11 @@ FILE *weechat_log_file = NULL; /* WeeChat log file */
/*
- * weechat_log_open: initialize log file
+ * log_open: initialize log file
*/
int
@@ -95,13 +95,13 @@ weechat_log_open (char *filename, char *mode)
}
/*
- * weechat_log_init: initialize log file
+ * log_init: initialize log file
*/
void
@@ -112,11 +112,11 @@ weechat_log_init ()
}
/*
- * weechat_log_printf: write a message in WeeChat log (<weechat_home>/weechat.log)
+ * log_printf: write a message in WeeChat log (<weechat_home>/weechat.log)
*/
void
@@ -156,11 +156,11 @@ weechat_log_printf (char *message, ...)
}
/*
- * weechat_log_close: close log file
+ * log_close: close log file
*/
void
@@ -181,11 +181,11 @@ weechat_log_close ()
}
/*
- * weechat_log_crash_rename: rename log file when crashing
+ * log_crash_rename: rename log file when crashing
*/
int